@@ -18,12 +18,13 @@
 /// TODO
 ///
 use crate::{
-    traits::Verifier, AuthenticationProof, Changes, Contact, Credential, CredentialAttribute,
-    CredentialFragment1, CredentialFragment2, CredentialOffer, CredentialPresentation,
-    CredentialProof, CredentialPublicKey, CredentialRequest, CredentialRequestFragment,
-    CredentialSchema, Entity, Handle, Holder, Identity, IdentityRequest, IdentityResponse, Issuer,
-    OfferId, PresentationManifest, ProfileChangeEvent, ProfileIdentifier, ProofRequestId,
-    SecureChannels, SigningPublicKey, TrustPolicy,
+    traits::Verifier, AuthenticationProof, BbsCredential, Changes, Contact, Credential,
+    CredentialAttribute, CredentialFragment1, CredentialFragment2, CredentialOffer,
+    CredentialPresentation, CredentialProof, CredentialPublicKey, CredentialRequest,
+    CredentialRequestFragment, CredentialSchema, Entity, EntityCredential, Handle, Holder,
+    Identity, IdentityRequest, IdentityResponse, Issuer, OfferId, PresentationManifest,
+    ProfileChangeEvent, ProfileIdentifier, ProofRequestId, SecureChannels, SigningPublicKey,
+    TrustPolicy,
 };
 use ockam_core::{Address, Result, Route};
 use ockam_vault::{PublicKey, Secret};
@@ -37,7 +38,7 @@ pub struct Profile {
 
 impl From<Profile> for Entity {
     fn from(p: Profile) -> Entity {
-        Entity::new(p.handle.clone(), p.id.clone())
+        Entity::new(p.handle.clone(), Some(p.id.clone()))
     }
 }
 
@@ -197,7 +198,7 @@ impl Issuer for Profile {
         &self,
         schema: &CredentialSchema,
         attributes: A,
-    ) -> Result<Credential> {
+    ) -> Result<BbsCredential> {
         self.entity().sign_credential(schema, attributes)
     }
 
@@ -227,27 +228,38 @@ impl Holder for Profile {
         &self,
         credential_fragment1: CredentialFragment1,
         credential_fragment2: CredentialFragment2,
-    ) -> Result<Credential> {
+    ) -> Result<BbsCredential> {
         self.entity()
             .combine_credential_fragments(credential_fragment1, credential_fragment2)
     }
 
     fn is_valid_credential(
         &self,
-        credential: &Credential,
+        credential: &BbsCredential,
         verifier_key: SigningPublicKey,
     ) -> Result<bool> {
         self.entity().is_valid_credential(credential, verifier_key)
     }
 
-    fn present_credential(
+    fn create_credential_presentation(
         &self,
-        credential: &Credential,
+        credential: &BbsCredential,
         presentation_manifests: &PresentationManifest,
         proof_request_id: ProofRequestId,
     ) -> Result<CredentialPresentation> {
-        self.entity()
-            .present_credential(credential, presentation_manifests, proof_request_id)
+        self.entity().create_credential_presentation(
+            credential,
+            presentation_manifests,
+            proof_request_id,
+        )
+    }
+
+    fn add_credential(&mut self, credential: EntityCredential) -> Result<()> {
+        self.entity().add_credential(credential)
+    }
+
+    fn get_credential(&mut self, credential: &Credential) -> Result<EntityCredential> {
+        self.entity().get_credential(credential)
     }
 }
 
